============================================
Model Mommy: Smart fixtures for better tests
============================================

*Model-mommy* offers you a smart way to create fixtures for testing in Django.
With a simple and powerful API you can create many objects with a single line of code.

.. image:: https://travis-ci.org/vandersonmota/model_mommy.png?branch=master
    :target: https://travis-ci.org/vandersonmota/model_mommy
    :alt: Test Status

.. image:: https://pypip.in/v/model_mommy/badge.png
    :target: https://crate.io/packages/model_mommy/
    :alt: Latest PyPI version

.. image:: https://pypip.in/d/model_mommy/badge.png
    :target: https://crate.io/packages/model_mommy/
    :alt: Number of PyPI downloads

.. image:: https://img.shields.io/gratipay/vandersonmota.svg?style=social&label=Donate
    :target: https://www.gratipay.com/vandersonmota

Install
=======

.. code-block:: console

    pip install model_mommy


Usage and Info
==============

*     http://model-mommy.readthedocs.org/
